@@ -51,7 +51,7 @@ int main(int argc, char *argv[])
         usage(argv[0]);
 
     dbg = getenv("DEBUG");
-    if (NULL != dbg)
+    if (dbg)
         debug = atoi(dbg);
 
     FUNC;
