@@ -129,7 +129,7 @@ void file_update_inuse(unsigned char *stiger, INUSE * inuse)
     LDEBUG
         ("file_update_inuse : update inuse->size = %lu, inuse->inuse = %llu",
          inuse->size, inuse->inuse);
-    if (inuse != NULL) {
+    if (inuse) {
         bin_write_dbdata(DBU, stiger, config->hashlen,
                          (unsigned char *) inuse, sizeof(INUSE));
     }
@@ -371,7 +371,7 @@ DAT *file_tgr_read_data(unsigned char *stiger)
 
     FUNC;
     inuse = file_get_inuse(stiger);
-    if (NULL != inuse) {
+    if (inuse) {
         if (inuse->inuse == 0)
             die_dataerr("file_tgr_read_data : read empty block");
         LDEBUG("file_tgr_read_data : read offset %llu, size %lu",
@@ -637,7 +637,7 @@ void *file_truncate_worker(void *threadarg)
         create_hash_note(stiger);
         delete_dbb(&inobno);
         inuse = file_get_inuse(stiger);
-        if (NULL != inuse) {
+        if (inuse) {
             if (inuse->inuse == 1) {
                 if ( config->blockdata_io_type == CHUNK_IO ) {
                       chunk_delete(stiger,inuse->offset);
