@@ -28,7 +28,7 @@
 #include "lib_log.h"
 #endif
 
-#define LFSVERSION "1.5.9"
+#define LFSVERSION "1.7.0"
 
 #include <fuse.h>
 #include <stdio.h>
@@ -341,7 +341,7 @@ static int lessfs_unlink(const char *path)
     tctreeout(metatree, &stbuf->st_ino, sizeof(unsigned long long));
     release_meta_lock();
 
-    if (NULL != config->blockdatabs) {
+    if (config->blockdatabs) {
         res = db_unlink_file(path);
     } else {
         res = file_unlink_file(path);
@@ -464,7 +464,7 @@ static int lessfs_chmod(const char *path, mode_t mode)
     meta_lock((char *) __PRETTY_FUNCTION__);
     data = tctreeget(metatree, &stbuf.st_ino,
                      sizeof(unsigned long long), &vsize);
-    if (NULL != data) {
+    if (data) {
         memddstat = (MEMDDSTAT *) data;
         memddstat->stbuf.st_ctim.tv_sec = thetime;
         memddstat->stbuf.st_ctim.tv_nsec = 0;
@@ -511,7 +511,7 @@ static int lessfs_chown(const char *path, uid_t uid, gid_t gid)
     meta_lock((char *) __PRETTY_FUNCTION__);
     data = tctreeget(metatree, &stbuf.st_ino,
                      sizeof(unsigned long long), &vsize);
-    if (NULL != data) {
+    if (data) {
         memddstat = (MEMDDSTAT *) data;
         memddstat->stbuf.st_ctim.tv_sec = thetime;
         memddstat->stbuf.st_ctim.tv_nsec = 0;
@@ -572,7 +572,7 @@ static int lessfs_truncate(const char *path, off_t size)
     flush_wait(stbuf->st_ino);
     purge_read_cache(stbuf->st_ino, 1, (char *) __PRETTY_FUNCTION__);
     if (size < stbuf->st_size) {
-        if (NULL != config->blockdatabs) {
+        if (config->blockdatabs) {
             res = db_fs_truncate(stbuf, size, bname, 0);
         } else {
             res = file_fs_truncate(stbuf, size, bname, 0);
@@ -611,7 +611,7 @@ static int lessfs_utimens(const char *path, const struct timespec ts[2])
         goto out;
     data = tctreeget(metatree, &stbuf.st_ino,
                      sizeof(unsigned long long), &vsize);
-    if (NULL != data) {
+    if (data) {
         memddstat = (MEMDDSTAT *) data;
         memddstat->stbuf.st_atim.tv_sec = ts[0].tv_sec;
         memddstat->stbuf.st_atim.tv_nsec = ts[0].tv_nsec;
@@ -805,7 +805,7 @@ static int lessfs_read(const char *path, char *buf, size_t size,
     while (done < size) {
         blocknr = (offset + done) / BLKSIZE;
         block_offset = (done + offset) - (blocknr * BLKSIZE);
-        if (NULL != config->blockdatabs) {
+        if (config->blockdatabs) {
             got =
                 readBlock(blocknr, buf + done, size - done, block_offset,
                           fi->fh);
@@ -870,7 +870,7 @@ void add2cache(INOBNO * inobno, const char *buf, off_t offsetblock,
     key =
         (char *) tctreeget(readcachetree, (void *) inobno, sizeof(INOBNO),
                            &size);
-    if (NULL != key) {
+    if (key) {
         memcpy(&p, key, size);
         ccachedta = get_ccachedta(p);
         while (ccachedta->pending == 1) {
@@ -890,7 +890,7 @@ void add2cache(INOBNO * inobno, const char *buf, off_t offsetblock,
     update_filesize(inobno->inode, bsize, offsetblock, inobno->blocknr);
     if (bsize < BLKSIZE) {
         data = check_block_exists(inobno);
-        if (NULL != data) {
+        if (data) {
             create_hash_note(data->data);
             if (NULL == config->blockdatabs) {
                 ccachedta =
@@ -901,7 +901,7 @@ void add2cache(INOBNO * inobno, const char *buf, off_t offsetblock,
                                   offsetblock);
             }
             delete_hash_note(data->data);
-            if (NULL != ccachedta) {
+            if (ccachedta) {
                 memcpy(&ccachedta->data[offsetblock], buf, bsize);
                 if (ccachedta->datasize < offsetblock + bsize)
                     ccachedta->datasize = offsetblock + bsize;
@@ -1023,7 +1023,7 @@ static int lessfs_statfs(const char *path, struct statvfs *stbuf)
     int res;
     char *blockdatadir;
 
-    if (NULL != config->blockdatabs) {
+    if (config->blockdatabs) {
         res = statvfs(config->blockdata, stbuf);
     } else {
         blockdatadir = s_dirname(config->blockdata);
@@ -1048,7 +1048,7 @@ static int lessfs_release(const char *path, struct fuse_file_info *fi)
     meta_lock((char *) __PRETTY_FUNCTION__);
     dataptr =
         tctreeget(metatree, &fi->fh, sizeof(unsigned long long), &vsize);
-    if (dataptr != NULL) {
+    if (dataptr) {
         memddstat = (MEMDDSTAT *) dataptr;
         if (memddstat->opened == 1) {
             // Update the filesize when needed.
@@ -1101,7 +1101,7 @@ static int lessfs_fsync(const char *path, int isdatasync,
 static void lessfs_destroy(void *unused __attribute__ ((unused)))
 {
     FUNC;
-    LFATAL("Lessfs is going down, please wait");
+    LINFO("Lessfs is going down, please wait");
     config->shutdown = 1;
     if (config->replication_enabled) {
         LFATAL("Wait for active replication threads to shutdown");
@@ -1164,7 +1164,7 @@ int check_free_space(char *dbpath)
     dfree = 100 / dfree;
     minfree = getenv("MIN_SPACE_FREE");
     minclean = getenv("MIN_SPACE_CLEAN");
-    if (NULL != minfree) {
+    if (minfree) {
         mf = atoi(minfree);
         if (mf > 100 || mf < 1)
             mf = 10;
@@ -1172,7 +1172,7 @@ int check_free_space(char *dbpath)
         mf = 10;
     }
     startreclaim=getenv("START_RECLAIM");
-    if (NULL != startreclaim ) {
+    if (startreclaim ) {
         sr = atoi(startreclaim);
         if (sr > 100 || sr < 1)
             sr = 15;
@@ -1184,7 +1184,7 @@ int check_free_space(char *dbpath)
     if (dfree <= mf) {
         return (1);
     }
-    if (NULL != minclean) {
+    if (minclean) {
         mc = atoi(minclean);
         if (mc > 100 || mc < 1)
             mc = 15;
@@ -1344,7 +1344,7 @@ void *housekeeping_worker(void *arg)
                                config->meta);
                 break;
             case 3:
-                if (NULL != config->blockdatabs) {
+                if (config->blockdatabs) {
                     dbpath =
                         as_sprintf(__FILE__, __LINE__, "%s/blockdata.tch",
                                    config->blockdata);
@@ -1706,7 +1706,7 @@ void *init_worker(void *arg)
             inobnolistsort(keylist);
             key = (char *) tclistval(keylist, 0, &size);
             a = (char *) tctreeget(workqtree, (void *) key, size, &vsize);
-            if (NULL != a) {
+            if (a) {
                 memcpy(&p, a, vsize);
                 ccachedta = get_ccachedta(p);
                 dupkey = s_malloc(size);
@@ -1782,7 +1782,7 @@ int check_dirty()
     stiger = thash((unsigned char *) brand, strlen(brand));
     if (NULL == config->blockdatabs) {
         finuse = file_get_inuse(stiger);
-        if (NULL != finuse) {
+        if (finuse) {
             s_free(finuse);
             dirty = 1;
         }
@@ -1882,7 +1882,7 @@ static void *lessfs_init()
 #ifdef LZO
     initlzo();
 #endif
-    if (NULL != getenv("MAX_THREADS"))
+    if (getenv("MAX_THREADS"))
         max_threads = atoi(getenv("MAX_THREADS"));
     if (max_threads > MAX_ALLOWED_THREADS - 1)
         die_dataerr
@@ -2050,7 +2050,7 @@ int verify_kernel_version()
 
     for (count = 0; count < 3; count++) {
         end = strchr(begin, '.');
-        if (NULL != end) {
+        if (end) {
             end[0] = 0;
             end++;
         }
@@ -2094,10 +2094,10 @@ int main(int argc, char *argv[])
     int i;
     for (i = 1; i < argc - 1; i++) {
         argv_new[i] = argv[i + 1];
-        if (NULL != strstr(argv[i + 1], "big_writes")) {
+        if (strstr(argv[i + 1], "big_writes")) {
             maxwrite = strstr(argv[i + 1], "max_write=");
             maxread = strstr(argv[i + 1], "max_read=");
-            if (NULL != maxwrite && NULL != maxread) {
+            if (maxwrite && maxread) {
                 p = strchr(maxwrite, '=');
                 p++;
                 BLKSIZE = atoi(p);
@@ -2125,7 +2125,7 @@ int main(int argc, char *argv[])
         }
     }
 // Enable dumping of core for debugging.
-   if (NULL != getenv("COREDUMPSIZE")) {
+   if (getenv("COREDUMPSIZE")) {
         lessfslimit.rlim_cur = lessfslimit.rlim_max =
             atoi(getenv("COREDUMPSIZE"));
         if (0 != setrlimit(RLIMIT_CORE, &lessfslimit)) {
@@ -2142,7 +2142,7 @@ int main(int argc, char *argv[])
     signal(SIGALRM, normalExit);
     signal(SIGINT, normalExit);
     signal(SIGUSR1, libSafeExit);
-    if (NULL != getenv("DEBUG"))
+    if (getenv("DEBUG"))
         debug = atoi(getenv("DEBUG"));
     parseconfig(0, 0);
 
