@@ -247,7 +247,7 @@ void check_inode_structure(DDSTAT * ddstat)
 
     while (1) {
         data = fscheck_block_exists(inobno);
-        if (NULL != data) {
+        if (data) {
             blockdata = search_dbdata(DBDTA, data->data, data->size, LOCK);
             if (NULL == blockdata) {
                 printf("inode %llu-%llu\n", inobno.inode, inobno.blocknr);
@@ -295,7 +295,7 @@ void file_check_inode_structure(DDSTAT * ddstat)
 
     while (1) {
         data = fscheck_block_exists(inobno);
-        if (NULL != data) {
+        if (data) {
             blockdata = file_tgr_read_data(data->data);
             if (NULL == blockdata) {
                 printf("inode %llu-%llu\n", inobno.inode, inobno.blocknr);
@@ -368,7 +368,7 @@ int relink_symlink(DDSTAT * ddstat)
     data =
         search_dbdata(DBS, &ddstat->stbuf.st_ino,
                       sizeof(unsigned long long), LOCK);
-    if (NULL != data) {
+    if (data) {
         DATfree(data);
         ret = 0;
     }
@@ -526,7 +526,7 @@ void check_inodes()
                 ddstat = value_to_ddstat(data);
                 if (0 == check_inode_orphaned(ddstat)) {
                     if (S_ISREG(ddstat->stbuf.st_mode)) {
-                        if (NULL != config->blockdatabs) {
+                        if (config->blockdatabs) {
                             check_inode_structure(ddstat);
                         } else {
                             file_check_inode_structure(ddstat);
@@ -818,7 +818,7 @@ int main(int argc, char *argv[])
         parseconfig(0, 0);
     timeinfo = init_transactions();
     dbg = getenv("DEBUG");
-    if (NULL != dbg)
+    if (dbg)
         debug = atoi(dbg);
 
     if (0 == chkoptions.fast) {
@@ -829,7 +829,7 @@ int main(int argc, char *argv[])
         sleep(5);
     }
     BLKSIZE = get_blocksize();
-    if (NULL != config->blockdatabs) {
+    if (config->blockdatabs) {
         printf("**************************************************\n");
         printf("* Running lessfsck on a tc data store.           *\n");
         printf("**************************************************\n");
