@@ -209,7 +209,7 @@ void bdb_close()
         ret = ret_c;
     }
     /* Close the environment */
-    if (envp != NULL) {
+    if (envp) {
         ret_c = envp->close(envp, 0);
         if (ret_c != 0) {
             LFATAL("environment close failed: %s\n", db_strerror(ret_c));
@@ -323,7 +323,9 @@ void bdb_open()
     envp = NULL;
     u_int32_t db_flags, env_flags;
 
-    sp = s_dirname(config->blockdata);
+    if ( config->blockdata_io_type == FILE_IO ) {
+       sp = s_dirname(config->blockdata);
+    } else sp=s_strdup(config->blockdata);
     dbname = as_sprintf(__FILE__, __LINE__, "%s/replog.dta", sp);
     config->replication_logfile = s_strdup(dbname);
     if (-1 == (frepl = s_open2(dbname, O_CREAT | O_RDWR | O_NOATIME, S_IRWXU)))
@@ -609,7 +611,7 @@ void delete_key(int database, void *keydata, int len, const char *msg)
     key.size = len;
     key.flags = DB_DBT_USERMEM;
     if (0 != (res = db->del(db, txn, &key, 0))) {
-        if ( NULL != msg ) {
+        if (msg) {
            die_dataerr("Delete of key failed :%s", db_strerror(res));
         } else LINFO("Delete of key failed :%s", db_strerror(res));
     }
@@ -730,7 +732,7 @@ void btbin_write_dbdata(int database, void *keydata, int keylen,
     if (0 != res)
         die_dberr("btbin_write_dbdata : write failed %s",
                   db_strerror(res));
-    if (NULL != cur)
+    if (cur)
         cur->close(cur);
     release_bdb_lock();
     if (config->replication == 1 && config->replication_role == 0) {
@@ -797,7 +799,7 @@ void btbin_write_dup(int database, void *keydata, int keylen,
     if (0 != res)
         die_dberr("btbin_write_dup : write failed %s %llu database %u",
                   db_strerror(res), *inode, database);
-    if (NULL != cur)
+    if (cur)
         cur->close(cur);
     if (lock)
         release_bdb_lock();
@@ -833,7 +835,7 @@ int bt_entry_exists(int database, void *parent, int parentlen, void *value,
     db = bdb_set_db(database);
     db->cursor(db, txn, &cur, 0);
     res = cur->get(cur, &key, &data, DB_GET_BOTH | DB_READ_UNCOMMITTED);
-    if (NULL != cur)
+    if (cur)
         cur->close(cur);
     s_free(data.data);
     s_free(key.data);
@@ -906,22 +908,22 @@ INUSE *get_offset_reclaim(unsigned long long mbytes,
             cur->del(cur, 0);
             break;
         }
-        if (NULL != inuse)
+        if (inuse)
             break;
         if (!hasone)
             break;
-        if (NULL != cur)
+        if (cur)
             cur->close(cur);
         freelist->cursor(freelist, txn, &cur, 0);
     }
-    if (NULL != cur)
+    if (cur)
         cur->close(cur);
     s_free(data.data);
     s_free(key.data);
     release_bdb_lock();
-    if (NULL != inuse) {
+    if (inuse) {
         if (config->replication == 1 && config->replication_role == 0) {
-            if (NULL != freeblock) {
+            if (freeblock) {
                 write_repl_data(FREELIST, REPLDELETECURKEY,
                                 (char *) &asize,
                                 sizeof(unsigned long long),
@@ -991,14 +993,14 @@ unsigned long long get_offset_fast(unsigned long long mbytes)
                  cur->get(cur, &key, &data,
                           DB_NEXT_DUP | DB_READ_UNCOMMITTED));
     }
-    if (NULL != cur)
+    if (cur)
         cur->close(cur);
     s_free(data.data);
     s_free(key.data);
     release_bdb_lock();
     if (found) {
         if (config->replication == 1 && config->replication_role == 0) {
-            if (NULL != freeblock) {
+            if (freeblock) {
                 write_repl_data(FREELIST, REPLDELETECURKEY,
                                 (char *) &mbytes,
                                 sizeof(unsigned long long),
@@ -1116,6 +1118,7 @@ DDSTAT *dnode_bname_to_inode(void *dinode, int dlen, char *bname)
     /* Get a cursor */
     dbdirent->cursor(dbdirent, txn, &cur, DB_READ_UNCOMMITTED);
     DBTzero(&key);
+    DBTzero(&data);
 
     inode = s_zmalloc(sizeof(unsigned long long));
     data.data = s_zmalloc(1);
@@ -1165,7 +1168,7 @@ DDSTAT *dnode_bname_to_inode(void *dinode, int dlen, char *bname)
             fname =
                 btsearch_keyval(DBL, &dinoino, sizeof(DINOINO), bname,
                                 strlen(bname), NOLOCK);
-            if (NULL != fname) {
+            if (fname) {
                 lfilestat = s_zmalloc(sizeof(DDSTAT));
                 memcpy(lfilestat, statdata->data, statdata->size);
                 s_free(statdata);
@@ -1188,10 +1191,10 @@ DDSTAT *dnode_bname_to_inode(void *dinode, int dlen, char *bname)
   end:
     s_free(data.data);
     s_free(key.data);
-    if (cur != NULL)
+    if (cur)
         cur->close(cur);
     release_bdb_lock();
-    if (NULL != filestat) {
+    if (filestat) {
         LDEBUG("dnode_bname_to_inode : filestat->filename=%s inode %llu",
                filestat->filename,
                (unsigned long long) filestat->stbuf.st_ino);
@@ -1234,12 +1237,12 @@ unsigned long long has_nodes(unsigned long long inode)
         filedata =
             search_dbdata(DBP, filenode, sizeof(unsigned long long),
                           NOLOCK);
-        if (NULL != filedata) {
+        if (filedata) {
             ddstat = value_to_ddstat(filedata);
             DATfree(filedata);
             if (*filenode == inode)
                 dotdir = 1;
-            if (NULL != ddstat->filename) {
+            if (ddstat->filename) {
                 if (0 == strcmp(ddstat->filename, "."))
                     dotdir = 1;
                 if (0 == strcmp(ddstat->filename, ".."))
@@ -1260,7 +1263,7 @@ unsigned long long has_nodes(unsigned long long inode)
     s_free(key.data);
   end:
     s_free(data.data);
-    if (cur != NULL)
+    if (cur)
         cur->close(cur);
     release_bdb_lock();
     LDEBUG("has_nodes inode %llu contains %llu files", inode, res);
@@ -1310,7 +1313,7 @@ int fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
             if (0 != memcmp(data.data, key.data, key.size)) {
                 filedata =
                     search_dbdata(DBP, data.data, data.size, NOLOCK);
-                if (NULL != filedata) {
+                if (filedata) {
                     ddstat = value_to_ddstat(filedata);
                     DATfree(filedata);
                     if (ddstat->filename[0] == 0) {
@@ -1325,10 +1328,10 @@ int fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
                  cur->get(cur, &key, &data,
                           DB_NEXT_DUP | DB_READ_UNCOMMITTED));
     }
-    if (data.data != NULL)
+    if (data.data)
         s_free(data.data);
     s_free(key.data);
-    if (cur != NULL)
+    if (cur)
         cur->close(cur);
     release_bdb_lock();
     LDEBUG("fs_readdir: return");
@@ -1370,11 +1373,11 @@ void fs_read_hardlink(struct stat stbuf, DDSTAT * ddstat, void *buf,
                  cur->get(cur, &key, &data,
                           DB_NEXT_DUP | DB_READ_UNCOMMITTED));
     }
-    if (cur != NULL)
+    if (cur)
         cur->close(cur);
-    if (NULL != data.data)
+    if (data.data)
         s_free(data.data);
-    if (NULL != key.data)
+    if (key.data)
         s_free(key.data);
     EFUNC;
     return;
@@ -1411,11 +1414,11 @@ int count_dirlinks(void *linkstr, int len)
     } while (0 ==
              cur->get(cur, &key, &data,
                       DB_NEXT_DUP | DB_READ_UNCOMMITTED));
-    if (data.data != NULL)
+    if (data.data)
         s_free(data.data);
   end_exit:
     s_free(key.data);
-    if (cur != NULL)
+    if (cur)
         cur->close(cur);
     release_bdb_lock();
     EFUNC;
@@ -1439,7 +1442,7 @@ DAT *btsearch_keyval(int database, void *keydata, int keylen, void *val,
         bdb_lock((char *) __PRETTY_FUNCTION__);
     DBTzero(&key);
     DBTzero(&data);
-    if (NULL != val) {
+    if (val) {
         data.data = s_zmalloc(vallen);
         memcpy(data.data, val, vallen);
         data.size = vallen;
@@ -1456,7 +1459,7 @@ DAT *btsearch_keyval(int database, void *keydata, int keylen, void *val,
     key.flags = DB_DBT_REALLOC;
     /* Get a cursor */
     db->cursor(db, txn, &cur, 0);
-    if (NULL != val) {
+    if (val) {
         res =
             cur->get(cur, &key, &data, DB_GET_BOTH | DB_READ_UNCOMMITTED);
         if (res != 0) {
@@ -1485,7 +1488,7 @@ DAT *btsearch_keyval(int database, void *keydata, int keylen, void *val,
   end:
     s_free(key.data);
     s_free(data.data);
-    if (cur != NULL)
+    if (cur)
         cur->close(cur);
     if (lock)
         release_bdb_lock();
@@ -1521,14 +1524,14 @@ int btdelete_curkey(int database, void *keydata, int keylen, void *value,
     res = cur->get(cur, &key, &data, DB_GET_BOTH | DB_READ_UNCOMMITTED);
     if (res != 0) {
         LDEBUG("btdelete_curkey : %s", db_strerror(res));
-        if (cur != NULL)
+        if (cur)
             cur->close(cur);
         release_bdb_lock();
         ret = -ENOENT;
         goto end;
     }
     cur->del(cur, 0);
-    if (cur != NULL)
+    if (cur)
         cur->close(cur);
     release_bdb_lock();
     if (config->replication == 1 && config->replication_role == 0) {
@@ -1578,7 +1581,7 @@ void bdb_restart_truncation()
         }
         LINFO("Resume truncation of inode %llu", trunc_data->inode);
         create_inode_note(trunc_data->inode);
-        if (NULL != config->blockdatabs) {
+        if (config->blockdatabs) {
             if (0 !=
                 pthread_create(&truncate_thread, NULL, tc_truncate_worker,
                                (void *) trunc_data))
@@ -1594,7 +1597,7 @@ void bdb_restart_truncation()
     } while (0 ==
              cur->get(cur, &key, &value, DB_NEXT | DB_READ_UNCOMMITTED));
   end_exit:
-    if (key.data != NULL)
+    if (key.data)
         s_free(key.data);
     cur->close(cur);
     release_bdb_lock();
@@ -1834,9 +1837,9 @@ void listdbb()
         printf("%llu-%llu : %s\n", inode, blocknr, asc_hash);
         s_free(asc_hash);
     }
-    if (value.data != NULL)
+    if (value.data)
         s_free(value.data);
-    if (key.data != NULL)
+    if (key.data)
         s_free(key.data);
     cur->close(cur);
 }
@@ -1886,9 +1889,9 @@ void listfree(int freespace_summary)
         }
     }
     printf("Total available space in %s : %lu\n\n",config->blockdata,freespace);
-    if (value.data != NULL)
+    if (value.data)
         s_free(value.data);
-    if (key.data != NULL)
+    if (key.data)
         s_free(key.data);
     cur->close(cur);
     return;
@@ -1947,9 +1950,9 @@ void flistdbu()
                        inuse->allocated_size);
         }
     }
-    if (value.data != NULL)
+    if (value.data)
         s_free(value.data);
-    if (key.data != NULL)
+    if (key.data)
         s_free(key.data);
     cur->close(cur);
 }
