@@ -149,7 +149,7 @@ void hm_open()
     char *sp;
 
     ham_parameter_t envparameters[] = {
-        {HAM_PARAM_CACHESIZE, config->cachesize / 2},
+        {HAM_PARAM_CACHESIZE, config->hamsterdb_cachesize },
         {0, 0}
     };
 
@@ -172,52 +172,54 @@ void hm_open()
     s_free(sp);
     s_free(dbname);
     dbname = as_sprintf(__FILE__, __LINE__, "%s/lessfs.db", config->meta);
-    st = ham_env_new(&env);
-    if (st != HAM_SUCCESS)
-        ham_error("ham_env_new %s");
     if (config->transactions) {
-        st = ham_env_open_ex(env, dbname,
-                             HAM_DISABLE_MMAP | HAM_ENABLE_TRANSACTIONS | HAM_WRITE_THROUGH |
-                             HAM_AUTO_RECOVERY, envparameters);
+        st = ham_env_open(&env, dbname,
+                             HAM_DISABLE_MMAP | HAM_ENABLE_TRANSACTIONS | HAM_ENABLE_FSYNC,
+                             envparameters);
     } else {
-        st = ham_env_open_ex(env, dbname, HAM_DISABLE_MMAP, envparameters);
+        st = ham_env_open(&env, dbname, HAM_DISABLE_MMAP, envparameters);
     }
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open failed to open the databases");
     s_free(dbname);
+    /*
     for (i = 0; i < TOTAL_DATABASES; i++) {
         LDEBUG("ham_new %i", i);
         st = ham_new(&db[i]);
         if (st != HAM_SUCCESS)
             ham_error("ham_new");
-    }
-    st = ham_env_open_db(env, db[DBDTA], 1 + DBDTA, 0, 0);
+    }*/
+    st = ham_env_open_db(env, &db[DBDTA], 1 + DBDTA, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open_db (DBDTA)");
-    st = ham_env_open_db(env, db[DBU], 1 + DBU, 0, 0);
+    st = ham_env_open_db(env, &db[DBU], 1 + DBU, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open_db (DBU)");
-    st = ham_env_open_db(env, db[DBB], 1 + DBB, 0, 0);
+    st = ham_env_open_db(env, &db[DBB], 1 + DBB, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open_db (DBB)");
-    st = ham_env_open_db(env, db[DBP], 1 + DBP, 0, 0);
+    st = ham_env_open_db(env, &db[DBP], 1 + DBP, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open_db (DBP)");
-    st = ham_env_open_db(env, db[DBS], 1 + DBS, 0, 0);
+    st = ham_env_open_db(env, &db[DBS], 1 + DBS, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open_db (DBS)");
-    st = ham_env_open_db(env, db[DBL], 1 + DBL, 0, 0);
+    st = ham_env_open_db(env, &db[DBL], 1 + DBL, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open_db (DBL)");
-    st = ham_env_open_db(env, db[FREELIST], 1 + FREELIST, 0, 0);
+    st = ham_env_open_db(env, &db[FREELIST], 1 + FREELIST, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open_db (FREELIST)");
-    st = ham_env_open_db(env, db[DBDIRENT], 1 + DBDIRENT, 0, 0);
+    st = ham_env_open_db(env, &db[DBDIRENT], 1 + DBDIRENT, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_open_db (DBDIRENT)");
 
     if (config->transactions) {
-        ham_txn_begin(&txn, db[0], 0);
+#ifdef HAM_API_REVISION
+       ham_txn_begin(&txn, env, "lessfs",NULL,0);
+#else
+       ham_txn_begin(&txn, db[0], 0);
+#endif
     }
     open_trees();
     if ( config->blockdata_io_type == FILE_IO ) {
@@ -232,7 +234,7 @@ void hm_open()
             (char *) thash((unsigned char *) hashstr, strlen(hashstr));
         s_free(hashstr);
         data = search_dbdata(DBU, config->nexthash, config->hashlen, LOCK);
-        if (NULL == data) {
+        if (!data) {
             LINFO("Filesystem upgraded to support transactions");
             nextoffset = stbuf.st_size;
         } else {
@@ -294,53 +296,54 @@ void hm_create(bool createpath)
 
 
     ham_parameter_t envparameters[] = {
-        {HAM_PARAM_CACHESIZE, config->cachesize / 2},
+        {HAM_PARAM_CACHESIZE, config->hamsterdb_cachesize },
         {0, 0}
     };
-    st = ham_env_new(&env);
+    st = ham_env_create(&env, dbname,
+                        HAM_DISABLE_MMAP | HAM_ENABLE_TRANSACTIONS | HAM_ENABLE_FSYNC |
+                        HAM_AUTO_RECOVERY, 0660, envparameters);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_new %s");
-    st = ham_env_create_ex(env, dbname,
-                           HAM_ENABLE_RECOVERY | HAM_ENABLE_TRANSACTIONS,
-                           0664, envparameters);
-    if (st != HAM_SUCCESS)
-        ham_error("ham_env_create failed to create the databases");
     s_free(dbname);
-    for (i = 0; i < TOTAL_DATABASES; i++) {
+    /*for (i = 0; i < TOTAL_DATABASES; i++) {
         LDEBUG("ham_new %i", i);
         st = ham_new(&db[i]);
         if (st != HAM_SUCCESS)
             ham_error("ham_new");
-    }
-    st = ham_env_create_db(env, db[DBDTA], 1 + DBDTA, 0, dbuparameters);
+    }*/
+    st = ham_env_create_db(env, &db[DBDTA], 1 + DBDTA, 0, dbuparameters);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_create_db (DBDTA)");
-    st = ham_env_create_db(env, db[DBU], 1 + DBU, 0, dbuparameters);
+    st = ham_env_create_db(env, &db[DBU], 1 + DBU, 0, dbuparameters);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_create_db (DBU)");
-    st = ham_env_create_db(env, db[DBB], 1 + DBB, 0, dbbparameters);
+    st = ham_env_create_db(env, &db[DBB], 1 + DBB, 0, dbbparameters);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_create_db (DBB)");
-    st = ham_env_create_db(env, db[DBP], 1 + DBP, 0, dbpparameters);
+    st = ham_env_create_db(env, &db[DBP], 1 + DBP, 0, dbpparameters);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_create_db (DBP)");
-    st = ham_env_create_db(env, db[DBS], 1 + DBS, 0, 0);
+    st = ham_env_create_db(env, &db[DBS], 1 + DBS, 0, 0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_create_db (DBS)");
-    st = ham_env_create_db(env, db[DBL], 1 + DBL, HAM_ENABLE_DUPLICATES,
+    st = ham_env_create_db(env, &db[DBL], 1 + DBL, HAM_ENABLE_DUPLICATES,
                            0);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_create_db (DBL)");
-    st = ham_env_create_db(env, db[FREELIST], 1 + FREELIST,
+    st = ham_env_create_db(env, &db[FREELIST], 1 + FREELIST,
                            HAM_ENABLE_DUPLICATES, dbpparameters);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_create_db (FREELIST)");
-    st = ham_env_create_db(env, db[DBDIRENT], 1 + DBDIRENT,
+    st = ham_env_create_db(env, &db[DBDIRENT], 1 + DBDIRENT,
                            HAM_ENABLE_DUPLICATES, dbpparameters);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_create_db (DBDIRENT)");
     if (config->transactions) {
+#ifdef HAM_API_REVISION
+        ham_txn_begin(&txn, env, "lessfs",NULL,0);
+#else
         ham_txn_begin(&txn, db[0], 0);
+#endif
     }
     open_trees();
     if ( config->blockdata_io_type == FILE_IO ) {
@@ -354,8 +357,8 @@ void hm_create(bool createpath)
         config->nexthash =
             (char *) thash((unsigned char *) hashstr, strlen(hashstr));
         data = search_dbdata(DBU, config->nexthash, config->hashlen, LOCK);
-        if (NULL == data) {
-            LFATAL("Filesystem upgraded to support transactions");
+        if (!data) {
+            LINFO("Filesystem upgraded to support transactions");
             nextoffset = stbuf.st_size;
         } else {
             memcpy(&nextoffset, data->data, sizeof(unsigned long long));
@@ -389,7 +392,7 @@ int btdelete_curkey(int database, void *key, int keylen, void *kvalue,
     memset(&hamkey, 0, sizeof(hamkey));
     memset(&hamrecord, 0, sizeof(hamrecord));
 
-    st = ham_cursor_create(db[database], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[database],txn, 0);
     if (st != HAM_SUCCESS) {
         LFATAL("ham_cursor_create() failed with error %d\n", st);
         release_ham_lock();
@@ -400,7 +403,7 @@ int btdelete_curkey(int database, void *key, int keylen, void *kvalue,
     hamkey.size = keylen;
     /* traverse records */
 
-    st = ham_cursor_find(cursor, &hamkey, 0);
+    st = ham_cursor_find(cursor, &hamkey, 0, 0);
     if (st == HAM_SUCCESS) {
         /* traverse records */
         do {
@@ -448,7 +451,7 @@ DAT *search_dbdata(int database, void *key, int len, bool lock)
     hamkey.data = key;
     hamkey.size = len;
     if ((st =
-         ham_find(db[database], txn, &hamkey, &record,
+        ham_db_find(db[database], txn, &hamkey, &record,
                   0)) != HAM_SUCCESS) {
         LDEBUG("search_dbdata : nothing found in database %i return NULL",
                database);
@@ -487,12 +490,12 @@ DDSTAT *dnode_bname_to_inode(void *dinode, int dlen, char *bname)
     key.data = (char *) dinode;
     key.size = dlen;
 
-    st = ham_cursor_create(db[DBDIRENT], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBDIRENT], txn, 0);
     if (st != HAM_SUCCESS) {
         LFATAL("ham_cursor_create() failed with error %d\n", st);
         die_syserr();
     }
-    st = ham_cursor_find(cursor, &key, 0);
+    st = ham_cursor_find(cursor, &key, 0, 0);
     if (st == HAM_KEY_NOT_FOUND) {
         LINFO("Unable to find file existing in dbp.\n");
         goto end_error;
@@ -532,7 +535,7 @@ DDSTAT *dnode_bname_to_inode(void *dinode, int dlen, char *bname)
             fname =
                 btsearch_keyval(DBL, &dinoino, sizeof(DINOINO), bname,
                                 strlen(bname), NOLOCK);
-            if (NULL != fname) {
+            if (fname) {
                 memcpy(&filestat->filename, fname->data, fname->size);
                 filestat->filename[fname->size + 1] = 0;
                 DATfree(fname);
@@ -567,7 +570,7 @@ DAT *btsearch_keyval(int database, void *key, int keylen, void *val,
     memset(&hamrec, 0, sizeof(hamrec));
 
     /* create a new cursor */
-    st = ham_cursor_create(db[database], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[database], txn, 0);
     if (st)
         ham_error("ham_cursor_create");
 
@@ -575,14 +578,14 @@ DAT *btsearch_keyval(int database, void *key, int keylen, void *val,
     hamkey.size = keylen;
 
     /* traverse records */
-    st = ham_cursor_find(cursor, &hamkey, 0);
+    st = ham_cursor_find(cursor, &hamkey, 0, 0);
     if (st == HAM_SUCCESS) {
         do {
             if ((st =
                  ham_cursor_move(cursor, 0, &hamrec, 0)) != HAM_SUCCESS)
                 die_dberr
                     ("btsearch_keyval : expected a value after a succesfull find");
-            if (NULL != val) {
+            if (val) {
                 if (vallen == hamrec.size) {
                     if (0 == memcmp(val, hamrec.data, hamrec.size)) {
                         ret = s_zmalloc(sizeof(DAT));
@@ -623,12 +626,12 @@ int count_dirlinks(void *linkstr, int len)
 
     int count = 0;
     ham_lock((char *) __PRETTY_FUNCTION__);
-    st = ham_cursor_create(db[DBL], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBL], txn, 0);
     if (st)
         ham_error("ham_cursor_create");
     key.data = linkstr;
     key.size = len;
-    st = ham_cursor_find(cursor, &key, 0);
+    st = ham_cursor_find(cursor, &key, 0, 0);
     if (st == HAM_SUCCESS) {
         /* traverse records */
         do {
@@ -657,9 +660,9 @@ void delete_key(int database, void *keydata, int len, const char *msg)
     memset(&key, 0, sizeof(key));
     key.data = keydata;
     key.size = len;
-    st = ham_erase(db[database], txn, &key, 0);
+    st = ham_db_erase(db[database], txn, &key, 0);
     if (st != HAM_SUCCESS) {
-        if (NULL != msg) {
+        if (msg) {
             LFATAL("Failed to delete data from database %i : caller %s",
                    database, msg);
             ham_error("ham_erase");
@@ -697,9 +700,9 @@ char *lessfs_stats()
     memset(&key, 0, sizeof(key));
     memset(&rec, 0, sizeof(rec));
 
-    st = ham_get_key_count(db[DBP], txn, 0, (ham_u64_t *) & lcount);
+    st = ham_db_get_key_count(db[DBP], txn, 0, (ham_u64_t *) & lcount);
     if (st)
-        ham_error("ham_cursor_create");
+        ham_error("ham_get_key_count");
     lcount++;
     lines = s_malloc(lcount * sizeof(char *));
     lines[0] =
@@ -709,7 +712,7 @@ char *lessfs_stats()
     /* traverse records */
 
     /* create a new cursor */
-    st = ham_cursor_create(db[DBP], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBP], txn, 0);
     if (st)
         ham_error("ham_cursor_create");
 
@@ -783,7 +786,7 @@ void bin_write_dbdata(int database, void *keydata, int keylen,
     key.size = keylen;
     record.size = datalen;
     record.data = dataData;
-    st = ham_insert(db[database], txn, &key, &record, HAM_OVERWRITE);
+    st = ham_db_insert(db[database], txn, &key, &record, HAM_OVERWRITE);
     if (st != HAM_SUCCESS)
         ham_error("bin_write_dbdata");
     release_ham_lock();
@@ -809,7 +812,7 @@ void bin_write(int database, void *keydata, int keylen,
     key.size = keylen;
     record.size = datalen;
     record.data = dataData;
-    st = ham_insert(db[database], txn, &key, &record, HAM_OVERWRITE);
+    st = ham_db_insert(db[database], txn, &key, &record, HAM_OVERWRITE);
     if (st != HAM_SUCCESS)
         ham_error("bin_write");
     release_ham_lock();
@@ -836,7 +839,7 @@ void btbin_write_dup(int database, void *keydata, int keylen,
     record.data = dataData;
 
     LDEBUG("btbin_write_dup : before insert database %i", database);
-    st = ham_insert(db[database], txn, &key, &record, HAM_DUPLICATE);
+    st = ham_db_insert(db[database], txn, &key, &record, HAM_DUPLICATE);
     if (st != HAM_SUCCESS)
         ham_error("btbin_write_dup");
     LDEBUG("btbin_write_dup : after insert");
@@ -861,10 +864,9 @@ void hm_close(bool abort)
                                HAM_AUTO_CLEANUP | HAM_TXN_AUTO_COMMIT);
         }
     } else
-        st = ham_env_close(env, 0);
+        st = ham_env_close(env, HAM_AUTO_CLEANUP);
     if (st != HAM_SUCCESS)
         ham_error("ham_env_close failed");
-    ham_env_delete(env);
     release_ham_lock();
     close_trees();
     if ( config->blockdata_io_type == FILE_IO ) {
@@ -911,13 +913,13 @@ int fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
     ham_lock((char *) __PRETTY_FUNCTION__);
     memset(&key, 0, sizeof(key));
     memset(&rec, 0, sizeof(rec));
-    st = ham_cursor_create(db[DBDIRENT], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBDIRENT], txn, 0);
     if (st)
         ham_error("fs_readdir : failed to create cursor");
 
     key.data = &stbuf.st_ino;
     key.size = sizeof(unsigned long long);
-    st = ham_cursor_find(cursor, &key, 0);
+    st = ham_cursor_find(cursor, &key, 0, 0);
     if (st == HAM_SUCCESS) {
         do {
             if ((st = ham_cursor_move(cursor, 0, &rec, 0)) != HAM_SUCCESS)
@@ -926,7 +928,7 @@ int fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
             if (0 == memcmp(rec.data, key.data, key.size))
                 continue;
             filedata = search_dbdata(DBP, rec.data, rec.size, NOLOCK);
-            if (NULL != filedata) {
+            if (filedata) {
                 ddstat = value_to_ddstat(filedata);
                 DATfree(filedata);
                 if (ddstat->filename[0] == 0) {
@@ -960,7 +962,7 @@ void fs_read_hardlink(struct stat stbuf, DDSTAT * ddstat, void *buf,
     memset(&rec, 0, sizeof(rec));
 
     LDEBUG("fs_read_hardlink : %llu", (unsigned long long) stbuf.st_ino);
-    st = ham_cursor_create(db[DBL], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBL], txn, 0);
     if (st)
         ham_error("ham_cursor_create");
 
@@ -969,7 +971,7 @@ void fs_read_hardlink(struct stat stbuf, DDSTAT * ddstat, void *buf,
 
     key.data = &dinoino;
     key.size = sizeof(DINOINO);
-    st = ham_cursor_find(cursor, &key, 0);
+    st = ham_cursor_find(cursor, &key, 0, 0);
     if (st == HAM_SUCCESS) {
         do {
             if ((st = ham_cursor_move(cursor, 0, &rec, 0)) != HAM_SUCCESS) {
@@ -1004,12 +1006,12 @@ int bt_entry_exists(int database, void *parent, int parentlen, void *value,
     memset(&key, 0, sizeof(key));
     memset(&rec, 0, sizeof(rec));
     ham_lock((char *) __PRETTY_FUNCTION__);
-    st = ham_cursor_create(db[database], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[database], txn, 0);
     if (st)
         ham_error("bt_entry_exists : ham_cursor_create");
     key.data = parent;
     key.size = parentlen;
-    st = ham_cursor_find(cursor, &key, 0);
+    st = ham_cursor_find(cursor, &key, 0, 0);
     if (st == HAM_SUCCESS) {
         do {
             if ((st = ham_cursor_move(cursor, 0, &rec, 0)) != HAM_SUCCESS)
@@ -1045,14 +1047,14 @@ unsigned long long has_nodes(unsigned long long inode)
     memset(&rec, 0, sizeof(rec));
 
     ham_lock((char *) __PRETTY_FUNCTION__);
-    st = ham_cursor_create(db[DBDIRENT], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBDIRENT], txn, 0);
     if (st != HAM_SUCCESS) {
         return (-ENOENT);
     }
 
     key.data = &inode;
     key.size = sizeof(unsigned long long);
-    st = ham_cursor_find(cursor, &key, 0);
+    st = ham_cursor_find(cursor, &key, 0, 0);
     if (st == HAM_SUCCESS) {
         do {
             if ((st = ham_cursor_move(cursor, 0, &rec, 0)) != HAM_SUCCESS)
@@ -1065,13 +1067,13 @@ unsigned long long has_nodes(unsigned long long inode)
             filedata =
                 search_dbdata(DBP, &filenode, sizeof(unsigned long long),
                               NOLOCK);
-            if (NULL != filedata) {
+            if (filedata) {
                 ddstat = value_to_ddstat(filedata);
                 DATfree(filedata);
                 LDEBUG("Compare : %llu %llu", filenode, inode);
                 if (filenode == inode)
                     dotdir = 1;
-                if (NULL != ddstat->filename) {
+                if (ddstat->filename) {
                     if (0 == strcmp(ddstat->filename, "."))
                         dotdir = 1;
                     if (0 == strcmp(ddstat->filename, ".."))
@@ -1127,7 +1129,11 @@ void start_transactions()
 {
     if (config->transactions) {
         ham_lock((char *) __PRETTY_FUNCTION__);
+#ifdef HAM_API_REVISION
+        st = ham_txn_begin(&txn, env, "lessfs",NULL,0);
+#else
         st = ham_txn_begin(&txn, db[0], 0);
+#endif
         if (st != HAM_SUCCESS)
             ham_error("start_flush_commit : failed to start transaction");
         release_ham_lock();
@@ -1185,7 +1191,7 @@ void hm_restart_truncation()
     memset(&key, 0, sizeof(key));
     memset(&rec, 0, sizeof(rec));
 
-    st = ham_cursor_create(db[FREELIST], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[FREELIST], txn, 0);
     if (st != HAM_SUCCESS) {
         LWARNING("Failed to create cursor : cm_restart_truncation");
         release_ham_lock();
@@ -1193,7 +1199,7 @@ void hm_restart_truncation()
     }
     key.data = keystr;
     key.size = strlen(keystr);
-    st = ham_cursor_find(cursor, &key, 0);
+    st = ham_cursor_find(cursor, &key, 0, 0);
     if (st == HAM_SUCCESS) {
         /* traverse records */
         do {
@@ -1246,7 +1252,7 @@ void btbin_write_dbdata(int database, void *keydata, int keylen,
     key.size = keylen;
     record.size = datalen;
     record.data = dataData;
-    st = ham_insert(db[database], txn, &key, &record, HAM_DUPLICATE);
+    st = ham_db_insert(db[database], txn, &key, &record, HAM_DUPLICATE);
     if (st != HAM_SUCCESS)
         ham_error("bin_write_dbdata");
     release_ham_lock();
@@ -1278,7 +1284,7 @@ INUSE *get_offset_reclaim(unsigned long long mbytes,
     memset(&hamrec, 0, sizeof(hamrec));
 
     /* create a new cursor */
-    st = ham_cursor_create(db[FREELIST], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[FREELIST], txn, 0);
     if (st)
         ham_error("ham_cursor_create");
 
@@ -1344,12 +1350,12 @@ INUSE *get_offset_reclaim(unsigned long long mbytes,
             }
             break;
         }
-        if (NULL != inuse)
+        if (inuse)
             break;
         if (!hasone)
             break;
         ham_cursor_close(cursor);
-        st = ham_cursor_create(db[FREELIST], txn, 0, &cursor);
+        st = ham_cursor_create(&cursor, db[FREELIST], txn, 0);
         if (st)
             ham_error("ham_cursor_create");
     }
@@ -1379,7 +1385,7 @@ unsigned long long get_offset_fast(unsigned long long mbytes)
     memset(&hamrec, 0, sizeof(hamrec));
 
     /* create a new cursor */
-    st = ham_cursor_create(db[FREELIST], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[FREELIST], txn, 0);
     if (st)
         ham_error("ham_cursor_create");
 
@@ -1387,7 +1393,7 @@ unsigned long long get_offset_fast(unsigned long long mbytes)
     hamkey.size = sizeof(unsigned long long);
 
     /* Move to first matching key */
-    st = ham_cursor_find(cursor, &hamkey, 0);
+    st = ham_cursor_find(cursor, &hamkey, 0, 0);
     if (st != HAM_SUCCESS) {
         LDEBUG("get_offset : key not found in database %i.\n", FREELIST);
         goto end_error;
@@ -1455,7 +1461,7 @@ void list_symlinks()
     memset(&key, 0, sizeof(key));
     memset(&record, 0, sizeof(record));
 
-    st = ham_cursor_create(db[DBS], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBS], txn, 0);
     if (st != HAM_SUCCESS) {
         fprintf(stderr, "ham_cursor_create() failed with error %d\n", st);
         exit(-1);
@@ -1487,7 +1493,7 @@ void list_hardlinks()
     memset(&key, 0, sizeof(key));
     memset(&record, 0, sizeof(record));
 
-    st = ham_cursor_create(db[DBL], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBL], txn, 0);
     if (st != HAM_SUCCESS) {
         fprintf(stderr, "ham_cursor_create() failed with error %d\n", st);
         exit(-1);
@@ -1539,7 +1545,7 @@ void flistdbu()
     memset(&key, 0, sizeof(key));
     memset(&record, 0, sizeof(record));
 
-    st = ham_cursor_create(db[DBU], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBU], txn, 0);
     if (st != HAM_SUCCESS) {
         fprintf(stderr, "ham_cursor_create() failed with error %d\n", st);
         exit(-1);
@@ -1591,7 +1597,7 @@ void listdbp()
     memset(&key, 0, sizeof(key));
     memset(&record, 0, sizeof(record));
 
-    st = ham_cursor_create(db[DBP], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBP], txn, 0);
     if (st != HAM_SUCCESS) {
         fprintf(stderr, "ham_cursor_create() failed with error %d\n", st);
         exit(-1);
@@ -1660,7 +1666,7 @@ void listdirent()
     memset(&key, 0, sizeof(key));
     memset(&record, 0, sizeof(record));
 
-    st = ham_cursor_create(db[DBDIRENT], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBDIRENT], txn, 0);
     if (st != HAM_SUCCESS) {
         fprintf(stderr, "ham_cursor_create() failed with error %d\n", st);
         exit(-1);
@@ -1695,7 +1701,7 @@ void listdbb()
     memset(&key, 0, sizeof(key));
     memset(&record, 0, sizeof(record));
 
-    st = ham_cursor_create(db[DBB], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[DBB], txn, 0);
     if (st != HAM_SUCCESS) {
         fprintf(stderr, "ham_cursor_create() failed with error %d\n", st);
         exit(-1);
@@ -1733,7 +1739,7 @@ void listfree(int freespace_summary)
     memset(&key, 0, sizeof(key));
     memset(&record, 0, sizeof(record));
 
-    st = ham_cursor_create(db[FREELIST], txn, 0, &cursor);
+    st = ham_cursor_create(&cursor, db[FREELIST], txn, 0);
     if (st != HAM_SUCCESS) {
         fprintf(stderr, "ham_cursor_create() failed with error %d\n", st);
         exit(-1);
