@@ -535,7 +535,7 @@ void watchdir()
                    config->replication_watchdir);
             exit(EXIT_WDIR);
         }
-        while (NULL != (entry = readdir(dp))) {
+        while (entry = readdir(dp)) {
             sequence = get_sequence();
             if (-1 == stat(entry->d_name, &stbuf)) {
                 LINFO("watchdir: Error on stat %s\n", entry->d_name);
@@ -591,7 +591,7 @@ void *replication_worker(void *arg)
     char *crccalc;
     unsigned int nakcount = 0;
 
-    if (NULL != config->replication_watchdir) {
+    if (config->replication_watchdir) {
         watchdir();
         pthread_exit(NULL);
     }
