@@ -243,10 +243,10 @@ void memdeeptrace(void *addr, size_t size)
     MEMINFO *meminfo=NULL;
 
     tctreeiterinit(memtracetree);
-    while (NULL != (key = (char *) tctreeiternext(memtracetree, &ksize))) {
+    while (key = (char *) tctreeiternext(memtracetree, &ksize)) {
         val =
             (char *) tctreeget(memtracetree, (void *) key, ksize, &vsize);
-        if (NULL != val) {
+        if (val) {
             meminfo = (MEMINFO *) val;
         }
         if (meminfo->address > addr + size)
@@ -286,7 +286,7 @@ int delmem(void *addr, char *file, unsigned int line)
     p = (uintptr_t) addr;
     pthread_mutex_lock(&mem_mutex);
     dta = tctreeget(memtracetree, (void *) &p, sizeof(uintptr_t), &size);
-    if (NULL != dta) {
+    if (dta) {
         ret = tctreeout(memtracetree, (void *) &p, sizeof(uintptr_t));
     }
     pthread_mutex_unlock(&mem_mutex);
@@ -357,15 +357,14 @@ void leak_report()
     int vsize;
 
 
-    if (fp_write != NULL) {
+    if (fp_write) {
         sprintf(info, "%s\n", "Memory Leak Summary");
         fwrite(info, (strlen(info)), 1, fp_write);
         sprintf(info, "%s\n", "-----------------------------------");
         fwrite(info, (strlen(info)), 1, fp_write);
 
         tctreeiterinit(memtracetree);
-        while (NULL !=
-               (p = (uintptr_t *) tctreeiternext(memtracetree, &ksize))) {
+        while (p = (uintptr_t *) tctreeiternext(memtracetree, &ksize)) {
             meminfo =
                 (MEMINFO *) tctreeget(memtracetree, (void *) p, ksize,
                                       &vsize);
@@ -607,7 +606,7 @@ char **s_srtOpenDir(char *processDir)
     pcount = 0;
     allocated = 0;
     sortme = (char **) s_malloc(sizeof(char *));
-    while (NULL != (entry = readdir(dp))) {
+    while (entry = readdir(dp)) {
         if (-1 == stat(entry->d_name, &stbuf)) {
             continue;
         }
@@ -639,7 +638,7 @@ int dirCnt(char *processDir)
     if (NULL == (dp = (opendir(processDir)))) {
         ERRHANDLE("opendir %s failed in dirCnt\n", processDir);
     }
-    while (NULL != (entry = readdir(dp))) {
+    while (entry = readdir(dp)) {
         if (-1 == stat(entry->d_name, &stbuf)) {
             continue;
         }
@@ -700,7 +699,7 @@ int mkpath(const char *s, mode_t mode)
     else
         rv = 0;
   out:
-    if (up != NULL)
+    if (up)
         free(up);
     free(q);
     free(path);
