@@ -333,7 +333,7 @@ void tc_defrag()
         LINFO("metadata.tcb not optimized");
     if (!tchdboptimize(dbs, atol(config->symlinkbs), 0, 0, HDBTLARGE))
         LINFO("symlink.tch not optimized");
-    if (NULL != config->blockdatabs) {
+    if (config->blockdatabs) {
         if (!tchdboptimize
             (dbdta, atol(config->blockdatabs), 0, 0, HDBTLARGE))
             LINFO("blockdata.tch not optimized");
@@ -411,7 +411,7 @@ void tc_open(bool defrag, bool createpath, bool force_optimize)
     LDEBUG("Open database %s", dbpath);
     dbp = hashdb_open(dbpath, 0, atol(config->metabs), force_optimize);
     s_free(dbpath);
-    if (NULL != config->blockdatabs) {
+    if (config->blockdatabs) {
         dbpath =
             as_sprintf(__FILE__, __LINE__, "%s/blockdata.tch",
                        config->blockdata);
@@ -490,7 +490,7 @@ void tc_open(bool defrag, bool createpath, bool force_optimize)
     }
     LDEBUG("All databases are open");
     if (config->transactions) {
-        if (NULL != config->blockdatabs) {
+        if (config->blockdatabs) {
             tchdbtranbegin(dbdta);
         }
         tcbdbtranbegin(freelist);
@@ -731,7 +731,7 @@ DDSTAT *dnode_bname_to_inode(void *dinode, int dlen, char *bname)
 
     inode = (unsigned long long *) dinode;
     /* traverse records */
-    while ((dbkey = tcbdbcurkey(cur, &dbsize)) != NULL) {
+    while (dbkey = tcbdbcurkey(cur, &dbsize)) {
         curinode = (unsigned long long *) dbkey;
         if (*curinode != *inode) {
             //if (0 != memcmp(dbkey, dinode, dlen)) {
@@ -782,7 +782,7 @@ DDSTAT *dnode_bname_to_inode(void *dinode, int dlen, char *bname)
                 fname =
                     btsearch_keyval(DBL, &dinoino, sizeof(DINOINO), bname,
                                     strlen(bname), NOLOCK);
-                if (NULL != fname) {
+                if (fname) {
                     lfilestat = s_zmalloc(sizeof(DDSTAT));
                     memcpy(lfilestat, statdata->data, statdata->size);
                     s_free(statdata);
@@ -803,7 +803,7 @@ DDSTAT *dnode_bname_to_inode(void *dinode, int dlen, char *bname)
         tcbdbcurnext(cur);
     }
     tcbdbcurdel(cur);
-    if (NULL != filestat) {
+    if (filestat) {
         LDEBUG("dnode_bname_to_inode : filestat->filename=%s inode %lu",
                filestat->filename, filestat->stbuf.st_ino);
     } else {
@@ -871,7 +871,7 @@ int btdelete_curkey(int database, void *key, int keylen, void *kvalue,
         return (-ENOENT);
     }
     /* traverse records */
-    while ((dbkey = tcbdbcurkey(cur, &ksize)) != NULL) {
+    while (dbkey = tcbdbcurkey(cur, &ksize)) {
         if (0 != memcmp(dbkey, key, ksize)) {
             s_free(dbkey);
             break;
@@ -934,14 +934,14 @@ DAT *btsearch_keyval(int database, void *key, int keylen, void *val,
         return ret;
     }
     /* traverse records */
-    while ((dbkey = tcbdbcurkey(cur, &size)) != NULL) {
+    while (dbkey = tcbdbcurkey(cur, &size)) {
         if (0 != memcmp(dbkey, key, keylen)) {
             s_free(dbkey);
             break;
         }
         dbvalue = tcbdbcurval(cur, &size);
-        if (NULL != dbvalue) {
-            if (NULL != val) {
+        if (dbvalue) {
+            if (val) {
                 if (vallen == size) {
                     if (0 == memcmp(val, dbvalue, size)) {
                         ret = s_zmalloc(sizeof(DAT));
@@ -987,7 +987,7 @@ int count_dirlinks(void *linkstr, int len)
         return (-ENOENT);
     }
     /* traverse records */
-    while ((key = tcbdbcurkey(cur, &size)) != NULL) {
+    while (key = tcbdbcurkey(cur, &size)) {
         if (len == size) {
             if (0 == memcmp(key, linkstr, len)) {
                 count++;
@@ -1012,7 +1012,7 @@ void delete_key(int database, void *keydata, int len, const char *msg)
     db = tc_set_hashdb(database);
     if (!tchdbout(db, keydata, len)) {
         ecode = tchdbecode(db);
-        if (NULL != msg)
+        if (msg)
             die_dataerr("Delete of key failed %s:%s", msg,
                         tchdberrmsg(ecode));
     }
@@ -1045,7 +1045,7 @@ void tc_restart_truncation()
         return;
     }
     /* traverse records */
-    while ((dbkey = tcbdbcurkey(cur, &ksize)) != NULL) {
+    while (dbkey = tcbdbcurkey(cur, &ksize)) {
         if (0 != memcmp(dbkey, key, keylen) || ksize != keylen) {
             s_free(dbkey);
             break;
@@ -1056,7 +1056,7 @@ void tc_restart_truncation()
             break;
         LINFO("Resume truncation of inode %llu", trunc_data->inode);
         create_inode_note(trunc_data->inode);
-        if (NULL != config->blockdatabs) {
+        if (config->blockdatabs) {
             if (0 !=
                 pthread_create(&truncate_thread, NULL, tc_truncate_worker,
                                (void *) trunc_data))
@@ -1096,7 +1096,7 @@ unsigned long long has_nodes(unsigned long long inode)
         tcbdbcurdel(cur);
         return (-ENOENT);
     }
-    while ((key = tcbdbcurkey(cur, &size)) != NULL) {
+    while (key = tcbdbcurkey(cur, &size)) {
         memcpy(&keyval, key, sizeof(unsigned long long));
         if (keyval != inode) {
             s_free(key);
@@ -1107,13 +1107,13 @@ unsigned long long has_nodes(unsigned long long inode)
         filedata =
             search_dbdata(DBP, &filenode, sizeof(unsigned long long),
                           NOLOCK);
-        if (NULL != filedata) {
+        if (filedata) {
             ddstat = value_to_ddstat(filedata);
             DATfree(filedata);
             LDEBUG("Compare : %llu %llu", filenode, inode);
             if (filenode == inode)
                 dotdir = 1;
-            if (NULL != ddstat->filename) {
+            if (ddstat->filename) {
                 if (0 == strcmp(ddstat->filename, "."))
                     dotdir = 1;
                 if (0 == strcmp(ddstat->filename, ".."))
@@ -1156,7 +1156,7 @@ void fs_read_hardlink(struct stat stbuf, DDSTAT * ddstat, void *buf,
     if (!tcbdbcurjump(cur, &dinoino, sizeof(DINOINO))
         && tcbdbecode(dbl) != TCESUCCESS)
         die_dataerr("Unable to find linkname, run fsck.");
-    while ((linkkey = tcbdbcurkey(cur, &ksize)) != NULL) {
+    while (linkkey = tcbdbcurkey(cur, &ksize)) {
         if (0 != memcmp(linkkey, &dinoino, sizeof(DINOINO))) {
             LDEBUG("fs_read_hardlink : linkkey != dinoino");
             s_free(linkkey);
@@ -1213,7 +1213,7 @@ int fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
         tcbdbcurdel(cur);
         return (-ENOENT);
     }
-    while ((key = tcbdbcurkey(cur, &ksize)) != NULL) {
+    while (key = tcbdbcurkey(cur, &ksize)) {
         memcpy(&keynode, key, sizeof(unsigned long long));
         if (stbuf.st_ino != keynode) {
             s_free(key);
@@ -1231,7 +1231,7 @@ int fs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
         filedata =
             search_dbdata(DBP, &filenode, sizeof(unsigned long long),
                           NOLOCK);
-        if (NULL != filedata) {
+        if (filedata) {
             ddstat = value_to_ddstat(filedata);
             DATfree(filedata);
             if (ddstat->filename[0] == 0) {
@@ -1269,7 +1269,7 @@ int bt_entry_exists(int database, void *parent, int parentlen, void *value,
         tcbdbcurdel(cur);
         return (res);
     }
-    while ((key = tcbdbcurkey(cur, &ksize)) != NULL) {
+    while (key = tcbdbcurkey(cur, &ksize)) {
         if (ksize != parentlen) {
             s_free(key);
             break;
@@ -1333,7 +1333,7 @@ void drop_databases()
     if (-1 != stat(dbpath, &stbuf))
         unlink(dbpath);
     s_free(dbpath);
-    if (NULL != config->blockdatabs) {
+    if (config->blockdatabs) {
         dbpath =
             as_sprintf(__FILE__, __LINE__, "%s/blockdata.tch",
                        config->blockdata);
@@ -1372,7 +1372,7 @@ DAT *search_nhash(TCNDB * db, void *key, int len)
 
 void abort_transactions()
 {
-    if (config->blockdatabs != NULL) {
+    if (config->blockdatabs) {
         if (config->transactions)
             if (!tchdbtranabort(dbdta))
                 die_dataerr
@@ -1406,7 +1406,7 @@ void abort_transactions()
 
 void commit_transactions()
 {
-    if (config->blockdatabs != NULL) {
+    if (config->blockdatabs) {
         if (config->transactions)
             if (!tchdbtrancommit(dbdta))
                 die_dataerr
@@ -1463,7 +1463,7 @@ void start_flush_commit()
 void start_transactions()
 {
     if (config->transactions) {
-        if (config->blockdatabs != NULL) {
+        if (config->blockdatabs) {
             tchdbtranbegin(dbdta);
         } else
             tcbdbtranbegin(freelist);
@@ -1509,7 +1509,7 @@ char *lessfs_stats()
                    "  INODE             SIZE  COMPRESSED_SIZE            RATIO  FILENAME\n");
     /* traverse records */
     tchdbiterinit(dbp);
-    while ((key = tchdbiternext(dbp, &ksize)) != NULL) {
+    while (key = tchdbiternext(dbp, &ksize)) {
         if (0 != memcmp(key, nfi, 3) && 0 != memcmp(key, seq, 3)) {
             inode = (unsigned long long *) key;
             data =
@@ -1570,7 +1570,7 @@ INUSE *get_offset_reclaim(unsigned long long mbytes,
     while (1) {
         cur = tcbdbcurnew(freelist);
         tcbdbcurfirst(cur);
-        while ((dbkey = tcbdbcurkey(cur, &dbsize)) != NULL) {
+        while (dbkey = tcbdbcurkey(cur, &dbsize)) {
             if (dbsize == strlen("TRNCTD") || *dbkey < mbytes) {
                 s_free(dbkey);
                 tcbdbcurnext(cur);
@@ -1634,7 +1634,7 @@ INUSE *get_offset_reclaim(unsigned long long mbytes,
         tcbdbcurdel(cur);
         if (!hasone)
             break;
-        if (NULL != inuse)
+        if (inuse)
             break;
     }
     LDEBUG("get_offset_reclaim returns = %llu", offset);
@@ -1660,7 +1660,7 @@ unsigned long long get_offset_fast(unsigned long long mbytes)
            mbytes);
     cur = tcbdbcurnew(freelist);
     if (tcbdbcurjump(cur, (void *) &mbytes, sizeof(unsigned long long))) {
-        while ((dbkey = tcbdbcurkey(cur, &dbsize)) != NULL) {
+        while (dbkey = tcbdbcurkey(cur, &dbsize)) {
             if (0 == memcmp(dbkey, &mbytes, sizeof(unsigned long long))) {
                 if ((dboffset = tcbdbcurval(cur, &dbsize)) == NULL)
                     die_dataerr("get_offset_fast : No value for key");
@@ -1725,7 +1725,7 @@ void listdirent()
     /* traverse records */
     cur = tcbdbcurnew(dbdirent);
     tcbdbcurfirst(cur);
-    while ((key = tcbdbcurkey2(cur)) != NULL) {
+    while (key = tcbdbcurkey2(cur)) {
         memcpy(&dir, key, sizeof(dir));
         value = tcbdbcurval(cur, &size);;
         if (value) {
@@ -1753,7 +1753,7 @@ void listfree(int freespace_summary)
 
     cur = tcbdbcurnew(freelist);
     tcbdbcurfirst(cur);
-    while ((dbkey = tcbdbcurkey(cur, &dbsize)) != NULL) {
+    while (dbkey = tcbdbcurkey(cur, &dbsize)) {
         if (dbsize == strlen("TRNCTD")) {
             trunc_data =
                 (struct truncate_thread_data *) tcbdbcurval(cur, &dbsize);
@@ -1810,7 +1810,7 @@ void listdbp()
 
     /* traverse records */
     tchdbiterinit(dbp);
-    while ((key = tchdbiternext(dbp, &ksize)) != NULL) {
+    while (key = tchdbiternext(dbp, &ksize)) {
         if (0 == memcmp(key, nfi, 3) || 0 == memcmp(key, seq, 3)) {
             value = tchdbget(dbp, key, strlen(key), &size);
             memcpy(&inode, value, sizeof(unsigned long long));
@@ -1862,7 +1862,7 @@ void list_hardlinks()
     /* traverse records */
     cur = tcbdbcurnew(dbl);
     tcbdbcurfirst(cur);
-    while ((key = tcbdbcurkey(cur, &ksize)) != NULL) {
+    while (key = tcbdbcurkey(cur, &ksize)) {
         value = tcbdbcurval(cur, &size);
         if (ksize == sizeof(DINOINO)) {
             memcpy(&dinoino, key, sizeof(DINOINO));
@@ -1891,7 +1891,7 @@ void list_symlinks()
     unsigned long long inode;
     /* traverse records */
     tchdbiterinit(dbs);
-    while ((key = tchdbiternext(dbs, &size)) != NULL) {
+    while (key = tchdbiternext(dbs, &size)) {
         value = tchdbget(dbs, key, size, &sp);
         memcpy(&inode, key, sizeof(unsigned long long));
         printf("%llu : %s\n", inode, value);
@@ -1911,7 +1911,7 @@ void listdbb()
 
     /* traverse records */
     tchdbiterinit(dbb);
-    while ((key = tchdbiternext(dbb, &size)) != NULL) {
+    while (key = tchdbiternext(dbb, &size)) {
         value = tchdbget(dbb, key, size, &vsize);
         asc_hash = ascii_hash((unsigned char *) value);
         memcpy(&inode, key, sizeof(unsigned long long));
@@ -1932,7 +1932,7 @@ void listdta()
 
     /* traverse records */
     tchdbiterinit(dbdta);
-    while ((key = tchdbiternext2(dbdta)) != NULL) {
+    while (key = tchdbiternext2(dbdta)) {
         asc_hash = ascii_hash((unsigned char *) key);
         printf("%s\n", asc_hash);
         s_free(asc_hash);
@@ -1951,7 +1951,7 @@ void flistdbu()
 
     /* traverse records */
     tchdbiterinit(dbu);
-    while ((key = tchdbiternext2(dbu)) != NULL) {
+    while (key = tchdbiternext2(dbu)) {
         if (0 == memcmp(config->nexthash, key, config->hashlen)) {
             inuse = tchdbget(dbu, key, config->hashlen, &size);
             memcpy(&nextoffet, inuse, sizeof(unsigned long long));
@@ -1985,7 +1985,7 @@ void listdbu()
 
     /* traverse records */
     tchdbiterinit(dbu);
-    while ((key = tchdbiternext2(dbu)) != NULL) {
+    while (key = tchdbiternext2(dbu)) {
         value = tchdbget(dbu, key, config->hashlen, &size);
         asc_hash = ascii_hash((unsigned char *) key);
         memcpy(&counter, value, sizeof(counter));
