@@ -1,12 +1,9 @@
 #!/bin/sh -x
 umount /fuse
-rm /core.*
-rm /core
 rm -rf /data/mta/*
 rm -rf /data/dta/*
 logrotate -f /etc/logrotate.conf
 cp DB_CONFIG /data/mta
 ./mklessfs -c /etc/lessfs.cfg
 # Use the new lessfs.cfg syntax and let lessfs worry about the rest.
-#valgrind --tool=memcheck --leak-check=yes ./lessfs /etc/lessfs.cfg /fuse  -d
 ./lessfs /etc/lessfs.cfg /fuse
